import network
import socket
import time
from machine import Pin, ADC

ssid = 'Insert SSID'
password = 'Wireless Password'

wlan = network.WLAN(network.STA_IF)
wlan.active(True)
wlan.connect(ssid, password)

html = """<!DOCTYPE html>
<html>
<head>
    <title>Pico Voltmeter</title>
    <meta http-equiv="refresh" CONTENT="2">
</head>
<body> <h1>Pico Voltmeter</h1>
<p>%s</p>
</body>
</html>
"""

# value to convert from number to voltage
conversion_factor = 3.3/65535

def get_voltage_html ():
    html_string = ""
    # ADC 0 to 2 (GB23, GP27 and GP28
    for pin in range (0,3):
        int_value = machine.ADC(pin).read_u16()
        volt_value = int_value * conversion_factor
        html_string += "<p>Voltage on ADC pin {} = {:.2f}V</p>\n".format(pin, volt_value)
        time.sleep (0.2)
    
    return html_string
        
# Wait for connect or fail
max_wait = 10
while max_wait > 0:
    if wlan.status() < 0 or wlan.status() >= 3:
        break
    max_wait -= 1
    print('waiting for connection...')
    time.sleep(1)

# Handle connection error
if wlan.status() != 3:
    raise RuntimeError('network connection failed')
else:
    print('connected')
    status = wlan.ifconfig()
    print( 'ip = ' + status[0] )

# Open socket
addr = socket.getaddrinfo('0.0.0.0', 80)[0][-1]

s = socket.socket()
s.bind(addr)
s.listen(1)

print('listening on', addr)

# Listen for connections
while True:
    try:
        cl, addr = s.accept()
        print('client connected from', addr)
        request = cl.recv(1024)
        print(request)

        response = html % get_voltage_html()

        cl.send('HTTP/1.0 200 OK\r\nContent-type: text/html\r\n\r\n')
        cl.send(response)
        cl.close()

    except OSError as e:
        cl.close()
        print('connection closed')